

studiopulsee, the studiopulsee API is the memory of your animation production 
-------------------------------------------------------------

The studiopulsee API allows to store and manage the data of your animation/VFX
production. Through it, you can link all the tools of your pipeline and make
sure they are all synchronized.

A dedicated Python client, _, allows users to
integrate studiopulsee into the tools. 

|CI badge| |Downloads badge| |Discord badge|

Features
~~~~~~~~

studiopulsee can:

-  Store production data, such as projects, shots, assets, tasks, and file metadata.
-  Track the progress of your artists
-  Store preview files and version them
-  Provide folder and file paths for any task
-  Import and Export data to CSV files
-  Publish an event stream of changes

Installation and Documentation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Installation of studiopulsee requires the setup of third-party tools such as a database
instance, so it is recommended to follow the documentation:




Contributing
------------

Contributions are welcomed so long as the 


studiopulsee is based on Python and the `Flask <http://flask.pocoo.org/>`__
framework.

You can use the pre-commit hook for Black (a Python code formatter) before
committing:

.. code:: bash

    pip install pre-commit
    pre-commit install





Contributors
------------

* @Hi Tech Interprise()
* @Divyesh Gohil (studiopulsee) - *maintainer*

About authors
~~~~~~~~~~~~~

studiopulsee is , a company based in Mumbai. We help with animation and
VFX studios to collaborate better through efficient tooling. We already work
with more than 10 studios around the Maharashtra.



